Stan Math Library: stan/math/prim/scal/prob/cauchy_rng.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

cauchy_rng.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_PROB_CAUCHY_RNG_HPP
2 #define STAN_MATH_PRIM_SCAL_PROB_CAUCHY_RNG_HPP
3
4 #include <boost/random/cauchy_distribution.hpp>
5 #include <boost/random/variate_generator.hpp>
6 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
7 #include <stan/math/prim/scal/err/check_finite.hpp>
8 #include <stan/math/prim/scal/err/check_not_nan.hpp>
9 #include <stan/math/prim/scal/err/check_positive_finite.hpp>
10 #include <stan/math/prim/scal/fun/constants.hpp>
11 #include <stan/math/prim/scal/fun/log1p.hpp>
12 #include <stan/math/prim/scal/fun/square.hpp>
13 #include <stan/math/prim/scal/fun/value_of.hpp>
14 #include <stan/math/prim/scal/meta/include_summand.hpp>
15
16 namespace stan {
17
18 namespace math {
19
20 template <class RNG>
21 inline double
22 cauchy_rng(const double mu,
23 const double sigma,
24 RNG& rng) {
25 using boost::variate_generator;
26 using boost::random::cauchy_distribution;
27
28 static const char* function("stan::math::cauchy_rng");
29
30 using stan::math::check_positive_finite;
31 using stan::math::check_finite;
32
33 check_finite(function, "Location parameter", mu);
34 check_positive_finite(function, "Scale parameter", sigma);
35
36 variate_generator<RNG&, cauchy_distribution<> >
37 cauchy_rng(rng, cauchy_distribution<>(mu, sigma));
38 return cauchy_rng();
39 }
40 }
41 }
42 #endif
check_not_nan.hpp
check_positive_finite.hpp
stan
Definition: log_sum_exp.hpp:8
square.hpp
include_summand.hpp
stan::math::cauchy_rng
double cauchy_rng(const double mu, const double sigma, RNG &rng)
Definition: cauchy_rng.hpp:22
stan::math::check_finite
bool check_finite(const char *function, const char *name, const T_y &y)
Return true if y is finite.
Definition: check_finite.hpp:62
constants.hpp
check_finite.hpp
log1p.hpp
value_of.hpp
check_consistent_sizes.hpp
stan::math::check_positive_finite
bool check_positive_finite(const char *function, const char *name, const T_y &y)
Return true if y is positive and finite.
Definition: check_positive_finite.hpp:28

[ Stan Home Page ] © 2011–2016, Stan Development Team.